import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Message, proto3 } from "@bufbuild/protobuf";
import { Completion, CompletionSource, EditorOptions, ExperimentKey, Language, Metadata } from "../codeium_common_pb/codeium_common_pb";
export declare enum CodeiumState {
    UNSPECIFIED = 0,
    INACTIVE = 1,
    PROCESSING = 2,
    SUCCESS = 3,
    WARNING = 4,
    ERROR = 5
}
export declare enum LineType {
    UNSPECIFIED = 0,
    SINGLE = 1,
    MULTI = 2
}
export declare enum CompletionPartType {
    UNSPECIFIED = 0,
    INLINE = 1,
    BLOCK = 2,
    INLINE_MASK = 3
}
export declare class GetCompletionsRequest extends Message<GetCompletionsRequest> {
    metadata?: Metadata;
    document?: Document;
    editorOptions?: EditorOptions;
    otherDocuments: Document[];
    experimentConfig?: ExperimentConfig;
    modelName: string;
    constructor(data?: PartialMessage<GetCompletionsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.GetCompletionsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetCompletionsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetCompletionsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetCompletionsRequest;
    static equals(a: GetCompletionsRequest | PlainMessage<GetCompletionsRequest> | undefined, b: GetCompletionsRequest | PlainMessage<GetCompletionsRequest> | undefined): boolean;
}
export declare class GetCompletionsResponse extends Message<GetCompletionsResponse> {
    state?: State;
    completionItems: CompletionItem[];
    constructor(data?: PartialMessage<GetCompletionsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.GetCompletionsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetCompletionsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetCompletionsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetCompletionsResponse;
    static equals(a: GetCompletionsResponse | PlainMessage<GetCompletionsResponse> | undefined, b: GetCompletionsResponse | PlainMessage<GetCompletionsResponse> | undefined): boolean;
}
export declare class AcceptCompletionRequest extends Message<AcceptCompletionRequest> {
    metadata?: Metadata;
    completionId: string;
    constructor(data?: PartialMessage<AcceptCompletionRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.AcceptCompletionRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): AcceptCompletionRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): AcceptCompletionRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): AcceptCompletionRequest;
    static equals(a: AcceptCompletionRequest | PlainMessage<AcceptCompletionRequest> | undefined, b: AcceptCompletionRequest | PlainMessage<AcceptCompletionRequest> | undefined): boolean;
}
export declare class AcceptCompletionResponse extends Message<AcceptCompletionResponse> {
    constructor(data?: PartialMessage<AcceptCompletionResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.AcceptCompletionResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): AcceptCompletionResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): AcceptCompletionResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): AcceptCompletionResponse;
    static equals(a: AcceptCompletionResponse | PlainMessage<AcceptCompletionResponse> | undefined, b: AcceptCompletionResponse | PlainMessage<AcceptCompletionResponse> | undefined): boolean;
}
export declare class GetAuthTokenRequest extends Message<GetAuthTokenRequest> {
    constructor(data?: PartialMessage<GetAuthTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.GetAuthTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetAuthTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetAuthTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetAuthTokenRequest;
    static equals(a: GetAuthTokenRequest | PlainMessage<GetAuthTokenRequest> | undefined, b: GetAuthTokenRequest | PlainMessage<GetAuthTokenRequest> | undefined): boolean;
}
export declare class GetAuthTokenResponse extends Message<GetAuthTokenResponse> {
    authToken: string;
    uuid: string;
    constructor(data?: PartialMessage<GetAuthTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.GetAuthTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetAuthTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetAuthTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetAuthTokenResponse;
    static equals(a: GetAuthTokenResponse | PlainMessage<GetAuthTokenResponse> | undefined, b: GetAuthTokenResponse | PlainMessage<GetAuthTokenResponse> | undefined): boolean;
}
export declare class DocumentPosition extends Message<DocumentPosition> {
    row: bigint;
    col: bigint;
    constructor(data?: PartialMessage<DocumentPosition>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.DocumentPosition";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DocumentPosition;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DocumentPosition;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DocumentPosition;
    static equals(a: DocumentPosition | PlainMessage<DocumentPosition> | undefined, b: DocumentPosition | PlainMessage<DocumentPosition> | undefined): boolean;
}
export declare class Document extends Message<Document> {
    absolutePath: string;
    relativePath: string;
    text: string;
    editorLanguage: string;
    language: Language;
    cursorOffset: bigint;
    cursorPosition?: DocumentPosition;
    lineEnding: string;
    constructor(data?: PartialMessage<Document>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.Document";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Document;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Document;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Document;
    static equals(a: Document | PlainMessage<Document> | undefined, b: Document | PlainMessage<Document> | undefined): boolean;
}
export declare class ExperimentConfig extends Message<ExperimentConfig> {
    forceEnableExperiments: ExperimentKey[];
    constructor(data?: PartialMessage<ExperimentConfig>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.ExperimentConfig";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ExperimentConfig;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ExperimentConfig;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ExperimentConfig;
    static equals(a: ExperimentConfig | PlainMessage<ExperimentConfig> | undefined, b: ExperimentConfig | PlainMessage<ExperimentConfig> | undefined): boolean;
}
export declare class State extends Message<State> {
    state: CodeiumState;
    message: string;
    constructor(data?: PartialMessage<State>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.State";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): State;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): State;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): State;
    static equals(a: State | PlainMessage<State> | undefined, b: State | PlainMessage<State> | undefined): boolean;
}
export declare class Range extends Message<Range> {
    startOffset: bigint;
    endOffset: bigint;
    startPosition?: DocumentPosition;
    endPosition?: DocumentPosition;
    constructor(data?: PartialMessage<Range>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.Range";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Range;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Range;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Range;
    static equals(a: Range | PlainMessage<Range> | undefined, b: Range | PlainMessage<Range> | undefined): boolean;
}
export declare class Suffix extends Message<Suffix> {
    text: string;
    deltaCursorOffset: bigint;
    constructor(data?: PartialMessage<Suffix>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.Suffix";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Suffix;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Suffix;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Suffix;
    static equals(a: Suffix | PlainMessage<Suffix> | undefined, b: Suffix | PlainMessage<Suffix> | undefined): boolean;
}
export declare class CompletionPart extends Message<CompletionPart> {
    text: string;
    offset: bigint;
    type: CompletionPartType;
    prefix: string;
    line: bigint;
    constructor(data?: PartialMessage<CompletionPart>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.CompletionPart";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CompletionPart;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CompletionPart;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CompletionPart;
    static equals(a: CompletionPart | PlainMessage<CompletionPart> | undefined, b: CompletionPart | PlainMessage<CompletionPart> | undefined): boolean;
}
export declare class CompletionItem extends Message<CompletionItem> {
    completion?: Completion;
    suffix?: Suffix;
    range?: Range;
    source: CompletionSource;
    completionParts: CompletionPart[];
    constructor(data?: PartialMessage<CompletionItem>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "exa.language_server_pb.CompletionItem";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CompletionItem;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CompletionItem;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CompletionItem;
    static equals(a: CompletionItem | PlainMessage<CompletionItem> | undefined, b: CompletionItem | PlainMessage<CompletionItem> | undefined): boolean;
}
